diff --git a/NKC_WF/WebUserControls/cmp_searchItems.ascx b/NKC_WF/WebUserControls/cmp_searchItems.ascx
new file mode 100644
index 0000000..2fcb643
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_searchItems.ascx
@@ -0,0 +1 @@
+<%@ Control Language="C#" AutoEventWireup="true" CodeBehind="cmp_searchItems.ascx.cs" Inherits="NKC_WF.WebUserControls.cmp_searchItems" %>
diff --git a/NKC_WF/WebUserControls/cmp_searchItems.ascx.cs b/NKC_WF/WebUserControls/cmp_searchItems.ascx.cs
new file mode 100644
index 0000000..805fad4
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_searchItems.ascx.cs
@@ -0,0 +1,17 @@
+using System;
+using System.Collections.Generic;
+using System.Linq;
+using System.Web;
+using System.Web.UI;
+using System.Web.UI.WebControls;
+
+namespace NKC_WF.WebUserControls
+{
+ public partial class cmp_searchItems : System.Web.UI.UserControl
+ {
+ protected void Page_Load(object sender, EventArgs e)
+ {
+
+ }
+ }
+}
\ No newline at end of file
diff --git a/NKC_WF/WebUserControls/cmp_searchItems.ascx.designer.cs b/NKC_WF/WebUserControls/cmp_searchItems.ascx.designer.cs
new file mode 100644
index 0000000..0b09990
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_searchItems.ascx.designer.cs
@@ -0,0 +1,17 @@
+//------------------------------------------------------------------------------
+//
+// Codice generato da uno strumento.
+//
+// Le modifiche a questo file possono causare un comportamento non corretto e verranno perse se
+// il codice viene rigenerato.
+//
+//------------------------------------------------------------------------------
+
+namespace NKC_WF.WebUserControls
+{
+
+
+ public partial class cmp_searchItems
+ {
+ }
+}
diff --git a/NKC_WF/site/GlobalSearch.aspx b/NKC_WF/site/GlobalSearch.aspx
index ef81f51..45edfdf 100644
--- a/NKC_WF/site/GlobalSearch.aspx
+++ b/NKC_WF/site/GlobalSearch.aspx
@@ -1,7 +1,11 @@
<%@ Page Title="" Language="C#" MasterPageFile="~/SiteContent.master" AutoEventWireup="true" CodeBehind="GlobalSearch.aspx.cs" Inherits="NKC_WF.site.GlobalSearch" %>
-<%@ Register Src="~/WebUserControls/tpl_WIP.ascx" TagPrefix="uc1" TagName="tpl_WIP" %>
+<%@ Register Src="~/WebUserControls/cmp_barcode.ascx" TagPrefix="uc1" TagName="cmp_barcode" %>
+<%@ Register Src="~/WebUserControls/cmp_searchItems.ascx" TagPrefix="uc1" TagName="cmp_searchItems" %>
+
+
-
+
+
diff --git a/NKC_WF/site/GlobalSearch.aspx.designer.cs b/NKC_WF/site/GlobalSearch.aspx.designer.cs
index 5547000..8615914 100644
--- a/NKC_WF/site/GlobalSearch.aspx.designer.cs
+++ b/NKC_WF/site/GlobalSearch.aspx.designer.cs
@@ -11,16 +11,25 @@ namespace NKC_WF.site
{
- public partial class GlobalSearch
- {
+ public partial class GlobalSearch
+ {
- ///
- /// Controllo tpl_WIP.
- ///
- ///
- /// Campo generato automaticamente.
- /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
- ///
- protected global::NKC_WF.WebUserControls.tpl_WIP tpl_WIP;
- }
+ ///
+ /// Controllo cmp_barcode.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::NKC_WF.WebUserControls.cmp_barcode cmp_barcode;
+
+ ///
+ /// Controllo cmp_searchItems.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::NKC_WF.WebUserControls.cmp_searchItems cmp_searchItems;
+ }
}